# Contributing

1.  Ideally, first make an issue to explain what you are intending to do. This
    might save you time and help you vet your proposed change.

2.  Fork, branch, and implement your desired changes. Please write at least one
    test, especially if this is a bugfix. Do NOT modify the version number.

3.  Run the tests with `python setup.py test`.

4.  Create a pull request.

5.  If your pull request passes the build, it will get a :+1: from an original
    author, and you will be given contributor-level access to the repo.

6.  Merge your pull request! Your commits will be automatically squashed.

7.  An original author will (eventually) release a new version.
